@@ -10,7 +10,7 @@ our @ISA         = qw(Exporter);
 our %EXPORT_TAGS = ( all => [ qw(slurp_xml) ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
-our $VERSION     = '0.42';
+our $VERSION     = '0.43';
 
 my $use_module;
 
@@ -803,7 +803,7 @@ sub slurp_xml {
 
 package XML::Reader::Token;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 sub found_start_tag   { $_[0][0] eq '<'; }
 sub found_end_tag     { $_[0][0] eq '>'; }
@@ -1981,7 +1981,7 @@ Option dupatt is only available if XML::Reader has been used with the XML::Parse
 option.
 
 For example, the following code allows for duplicate attributes concatenated by character
-"|":
+"|": (The concatenation string {dupatt => $str} is restricted to printable ascii excluding alphanumeric, " and ')
 
   use XML::Reader qw(XML::Parsepp);
 
